import { __awaiter } from "tslib";
import { retryableFetch } from '../utils/retryableFetch';
export function isLocalSdkConfig(config) {
    return config.env === 'local';
}
function isValidConfiguration(remoteConfig) {
    if (typeof remoteConfig !== 'object' || remoteConfig === null) {
        console.error('Invalid configuration type');
        return false;
    }
    if (!('env' in remoteConfig &&
        typeof remoteConfig['env'] === 'string' &&
        ['local', 'devel', 'prod'].includes(remoteConfig['env']))) {
        console.error(`Invalid env configuration`);
        return false;
    }
    const nonEmptyStringPropertyList = [
        'gameId',
        'apiKey',
        'appId',
        'authDomain',
        'messagingSenderId',
        'projectId',
        'storageBucket',
    ];
    for (const nonEmptyStringProperty of nonEmptyStringPropertyList) {
        if (!(nonEmptyStringProperty in remoteConfig &&
            typeof remoteConfig[nonEmptyStringProperty] ===
                'string' &&
            !!remoteConfig[nonEmptyStringProperty])) {
            console.error(`Invalid ${nonEmptyStringProperty} configuration`);
            return false;
        }
    }
    return true;
}
export function getConfig() {
    return __awaiter(this, arguments, void 0, function* (configurationLocation = './_p00ls-games/sdk-configuration.json') {
        console.debug('Using configuration location', configurationLocation);
        const remoteConfigFetch = yield retryableFetch(configurationLocation);
        const remoteConfig = yield remoteConfigFetch.json();
        if (isValidConfiguration(remoteConfig)) {
            return remoteConfig;
        }
        console.debug('remoteConfig:', remoteConfig);
        console.error(`Failed to parse config: ${configurationLocation}`);
        throw new Error(`Failed to parse SDK config`);
    });
}
//# sourceMappingURL=config.js.map