import { __awaiter } from "tslib";
import { createAnalyticsLog } from './index';
export function createAdSonar({ appId, rewardedAdUnit, interstitialUnit }, logEvent, debug = false) {
    const log = createAnalyticsLog(logEvent, {
        ad_platform: 'AdSonar',
        app_id: appId,
    });
    const sonar = new Promise((resolve, reject) => {
        const tag = document.createElement('script');
        tag.src = `https://static.sonartech.io/lib/1.0.0/sonar.js?appId=${appId}${debug ? '&isDebug=true' : ''}`;
        tag.addEventListener('load', () => {
            if (window.Sonar) {
                resolve(window.Sonar);
            }
            else {
                reject(new Error("Couldn't find Sonar instance"));
            }
        });
        document.body.appendChild(tag);
    });
    function adsCall(sonar, type = 'interstitial') {
        const adUnit = type === 'interstitial' ? interstitialUnit : rewardedAdUnit;
        log(type === 'interstitial' ? 'interstitial' : 'rewarded_ad', {
            ad_unit: adUnit,
        });
        return new Promise((resolve, reject) => {
            sonar
                .show({
                adUnit,
                onClose: () => resolve(true),
            })
                .then((result) => {
                if (result.status === 'error') {
                    reject(new Error('Ad error: ' + result.message));
                }
            });
        });
    }
    return {
        show(type) {
            return __awaiter(this, void 0, void 0, function* () {
                return adsCall(yield sonar, type);
            });
        },
    };
}
//# sourceMappingURL=adSonarProvider.js.map