import { initializeAnalytics, logEvent as fbLogEvent, setDefaultEventParameters, } from 'firebase/analytics';
export function createAnalytics(app, gameId, debug, userId, trackingParams = {}) {
    const analytics = initializeAnalytics(app, {
        config: toAnalyticsParams(trackingParams, gameId, debug, userId),
    });
    function logEvent(eventName, eventParams) {
        if (eventName === 'page_view' &&
            eventParams &&
            typeof eventParams['page_path'] === 'string') {
            const pageLocation = new URL(eventParams['page_path'], document.location.href).toString();
            setDefaultEventParameters({
                page_location: pageLocation,
            });
        }
        fbLogEvent(analytics, eventName, eventParams);
    }
    return { logEvent };
}
function toAnalyticsParams(trackingParams, gameId, debug, userId) {
    // possible values for gtag : https://developers.google.com/analytics/devguides/collection/ga4/reference/config
    return Object.assign(Object.assign(Object.assign({ send_page_view: false, game_id: gameId }, (userId ? { user_id: userId } : {})), (debug ? { debug_mode: true } : {})), trackingParams);
}
export const fakeAnalytics = {
    logEvent: (name, params) => console.info('Fake analytics. Log', name, params),
};
//# sourceMappingURL=analytics.js.map