import { __awaiter } from "tslib";
import { retryableFetch } from '../utils/retryableFetch';
const endpoints = {
    devel: 'https://games-bot.devel.p00ls.io',
    prod: 'https://games-bot.prod.p00ls.io',
    local: '',
};
export function isBuyItemParams(params) {
    return params.itemId !== undefined;
}
export function isBuyCurrencyParams(params) {
    return params.symbol !== undefined;
}
function getEndpoint(config) {
    if (config.env === 'local') {
        return config.serverUrl;
    }
    return endpoints[config.env];
}
export function createP00lsBotApi(config) {
    const endpoint = getEndpoint(config);
    const baseApiUrl = new URL('api/', endpoint);
    console.debug('Using endpoint:', endpoint);
    function getCustomToken(initData) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield retryableFetch(`${endpoint}/auth`, {
                method: 'POST',
                body: JSON.stringify({ gameId: config.gameId, initData }),
                headers: { 'Content-Type': 'application/json' },
            });
            if (!data.ok) {
                throw new Error('Failed to authenticate');
            }
            return (yield data.json());
        });
    }
    function createInvoiceLink(p, idToken) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield retryableFetch(`${endpoint}/invoices`, {
                method: 'POST',
                body: JSON.stringify(p),
                headers: {
                    'Content-Type': 'application/json',
                    Authorization: `Bearer ${idToken}`,
                },
            });
            if (!data.ok) {
                throw new Error('Create invoice failed');
            }
            return (yield data.json());
        });
    }
    function getReferralLink(idToken) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield retryableFetch(`${endpoint}/referral-link`, {
                method: 'GET',
                headers: {
                    'Content-Type': 'application/json',
                    Authorization: `Bearer ${idToken}`,
                },
            });
            if (!data.ok) {
                throw new Error('Get referral link failed');
            }
            return (yield data.json());
        });
    }
    function sendApiRequest(idToken, targetUrl, fetchOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield retryableFetch(new URL(targetUrl, baseApiUrl), Object.assign(Object.assign({}, fetchOptions), { headers: Object.assign(Object.assign({}, fetchOptions.headers), { Authorization: `Bearer ${idToken}`, 'Content-Type': 'application/json' }) }));
            if (!data.ok) {
                throw new Error(`${targetUrl} failed: ${data.statusText}`);
            }
            return (yield data.json());
        });
    }
    return { getCustomToken, createInvoiceLink, getReferralLink, sendApiRequest };
}
//# sourceMappingURL=p00lsBotApi.js.map