import { __awaiter } from "tslib";
import { getAuth, signInWithCustomToken, setPersistence, inMemoryPersistence, } from 'firebase/auth';
function doCreateAuth(currentUser, userProfile, trackingParameters) {
    function getIdToken() {
        return __awaiter(this, void 0, void 0, function* () {
            return currentUser.getIdToken();
        });
    }
    return { getIdToken, userProfile, trackingParameters };
}
export function createAuth(initData, app, botApi) {
    return __awaiter(this, void 0, void 0, function* () {
        const auth = getAuth(app);
        yield setPersistence(auth, inMemoryPersistence);
        const { token, trackingParameters } = yield botApi.getCustomToken(initData);
        const { user } = yield signInWithCustomToken(auth, token);
        const idToken = yield user.getIdTokenResult();
        const userProfile = {
            userId: user.uid,
            firstName: idToken.claims['firstName'],
            username: idToken.claims['username'],
            isPremium: (idToken.claims['isPremium'] || false),
            game: idToken.claims['gameId'],
            referrer: idToken.claims['referrer'],
        };
        return doCreateAuth(user, userProfile, trackingParameters);
    });
}
export const fakeAuth = {
    getIdToken() {
        return Promise.resolve('');
    },
    userProfile: {
        userId: 'fakeId',
        firstName: 'Fake User',
        isPremium: false,
        game: '',
    },
    trackingParameters: {},
};
//# sourceMappingURL=auth.js.map