import { __awaiter } from "tslib";
export function delayedStore(inactivityFlushDelayMs, storeCallback, onStateChange) {
    let state = 'clean';
    const cache = new Map();
    let callbackTimer;
    function add(path, payload) {
        cache.set(path, payload);
        waitThenCommit();
    }
    function waitThenCommit() {
        dirty();
        clearTimeout(callbackTimer);
        callbackTimer = setTimeout(() => commit().catch(console.error), inactivityFlushDelayMs);
    }
    function commit() {
        return __awaiter(this, void 0, void 0, function* () {
            const dataToCommit = new Map(cache);
            cache.clear();
            yield saveChanges(dataToCommit);
        });
    }
    function saveChanges(dataToCommit) {
        return __awaiter(this, void 0, void 0, function* () {
            for (const data of dataToCommit) {
                try {
                    yield storeCallback(data[0], data[1]);
                }
                catch (err) {
                    console.error(err);
                }
            }
            clean();
        });
    }
    function getState() {
        return state;
    }
    function getData(path) {
        if (cache.has(path)) {
            return cache.get(path);
        }
        return undefined;
    }
    function dirty() {
        state = 'dirty';
        onStateChange(state);
    }
    function clean() {
        state = 'clean';
        onStateChange(state);
    }
    function flush() {
        return __awaiter(this, void 0, void 0, function* () {
            if (state == 'clean') {
                return;
            }
            clearTimeout(callbackTimer);
            return commit();
        });
    }
    return {
        add,
        getState,
        getData,
        flush,
    };
}
//# sourceMappingURL=delayedStore.js.map