import { FirebaseApp } from 'firebase/app';
import { SdkConfig } from './_config/types';
export declare function p00lsGamesSdk(configurationLocation?: string): Promise<{
    data: {
        saveUserData: (payload: Record<string, unknown>) => Promise<void>;
        getUserData: () => Promise<import("@firebase/firestore").DocumentData | undefined>;
        savePartData: (docKey: string, payload: Record<string, unknown>) => Promise<void>;
        readPartData: (docKey: string) => Promise<import("@firebase/firestore").DocumentData | undefined>;
        flush: () => Promise<void>;
    };
    auth: {
        getIdToken: () => Promise<string>;
        userProfile: import("./types").UserProfile;
        trackingParameters: import("./api/p00lsBotApi").TrackingParameters;
    };
    analytics: {
        logEvent: (eventName: string, eventParams?: Record<string, unknown>) => void;
    };
    tma: {
        ready(): void;
        haptic: {
            (type: "impact", style: import("@telegram-apps/sdk").ImpactHapticFeedbackStyle): void;
            (type: "notification", style: import("@telegram-apps/sdk").NotificationHapticFeedbackType): void;
            (type: "select"): void;
        };
        getServerTime: () => Promise<Date>;
        share: (url: string, description: string) => void;
        openLink: (url: string) => void;
        openTelegramLink: (path: string, shouldClose?: boolean) => void;
        openP00LSGamesLauncher: () => void;
        isInFullscreen: boolean;
        close: () => void;
    };
    purchase: {
        initPurchase: (params: import("./api/p00lsBotApi").PurchaseParams) => Promise<string>;
        onPurchase: (handler?: (e: {
            paymentId: string;
            purchaseParams: import("./api/p00lsBotApi").PurchaseParams;
            status: import("@telegram-apps/sdk").InvoiceStatus;
        }) => void) => void;
    };
    ads: import("./ads").Ads;
    referral: {
        getReferralLink: () => Promise<string>;
        getReferrer(): Promise<import("./types").Referrer | undefined>;
        getReferees: ({ next, pageSize, since, }: {
            next?: string;
            pageSize?: number;
            since?: Date;
        }) => Promise<import("./types").GetRefereesResult>;
        shareLink(message?: string): Promise<void>;
    };
    statistics: {
        changeDisplayName: (newName: string, custom?: boolean) => Promise<void>;
        updateValues: (updates: import("./types").StatisticsUpdateRequest) => Promise<void>;
        fetchValues: () => Promise<import("./types").UserStatisticValues>;
        fetchLeaderboardPosition: (statistic: string) => Promise<import("./types").UserPosition | undefined>;
        fetchLeaderboard: (statistic: string, { next, pageSize }?: {
            next?: string;
            pageSize?: number;
        }) => Promise<import("./types").Leaderboard>;
        fetchLeaderboardAround: (statistic: string, { pageSize }?: {
            pageSize?: number;
        }) => Promise<import("./types").Leaderboard>;
    };
    wallet: {
        fetchWallet: () => Promise<import("./types").Wallet>;
        _setInternalWallet: (wallet: import("./types").Wallet) => Promise<void>;
        changeWallet: () => void;
    };
}>;
declare function initInTMA(config: SdkConfig, fbApp: FirebaseApp): Promise<{
    data: {
        saveUserData: (payload: Record<string, unknown>) => Promise<void>;
        getUserData: () => Promise<import("@firebase/firestore").DocumentData | undefined>;
        savePartData: (docKey: string, payload: Record<string, unknown>) => Promise<void>;
        readPartData: (docKey: string) => Promise<import("@firebase/firestore").DocumentData | undefined>;
        flush: () => Promise<void>;
    };
    auth: {
        getIdToken: () => Promise<string>;
        userProfile: import("./types").UserProfile;
        trackingParameters: import("./api/p00lsBotApi").TrackingParameters;
    };
    analytics: {
        logEvent: (eventName: string, eventParams?: Record<string, unknown>) => void;
    };
    tma: {
        ready(): void;
        haptic: {
            (type: "impact", style: import("@telegram-apps/sdk").ImpactHapticFeedbackStyle): void;
            (type: "notification", style: import("@telegram-apps/sdk").NotificationHapticFeedbackType): void;
            (type: "select"): void;
        };
        getServerTime: () => Promise<Date>;
        share: (url: string, description: string) => void;
        openLink: (url: string) => void;
        openTelegramLink: (path: string, shouldClose?: boolean) => void;
        openP00LSGamesLauncher: () => void;
        isInFullscreen: boolean;
        close: () => void;
    };
    purchase: {
        initPurchase: (params: import("./api/p00lsBotApi").PurchaseParams) => Promise<string>;
        onPurchase: (handler?: (e: {
            paymentId: string;
            purchaseParams: import("./api/p00lsBotApi").PurchaseParams;
            status: import("@telegram-apps/sdk").InvoiceStatus;
        }) => void) => void;
    };
    ads: import("./ads").Ads;
    referral: {
        getReferralLink: () => Promise<string>;
        getReferrer(): Promise<import("./types").Referrer | undefined>;
        getReferees: ({ next, pageSize, since, }: {
            next?: string;
            pageSize?: number;
            since?: Date;
        }) => Promise<import("./types").GetRefereesResult>;
        shareLink(message?: string): Promise<void>;
    };
    statistics: {
        changeDisplayName: (newName: string, custom?: boolean) => Promise<void>;
        updateValues: (updates: import("./types").StatisticsUpdateRequest) => Promise<void>;
        fetchValues: () => Promise<import("./types").UserStatisticValues>;
        fetchLeaderboardPosition: (statistic: string) => Promise<import("./types").UserPosition | undefined>;
        fetchLeaderboard: (statistic: string, { next, pageSize }?: {
            next?: string;
            pageSize?: number;
        }) => Promise<import("./types").Leaderboard>;
        fetchLeaderboardAround: (statistic: string, { pageSize }?: {
            pageSize?: number;
        }) => Promise<import("./types").Leaderboard>;
    };
    wallet: {
        fetchWallet: () => Promise<import("./types").Wallet>;
        _setInternalWallet: (wallet: import("./types").Wallet) => Promise<void>;
        changeWallet: () => void;
    };
}>;
export type P00lsGamesSdk = Awaited<ReturnType<typeof initInTMA>>;
export {};
