import { __awaiter } from "tslib";
import { isBuyCurrencyParams, isBuyItemParams, } from '../api/p00lsBotApi';
import { on, postEvent } from '@telegram-apps/sdk';
export const createFakePurchase = () => {
    let purchaseCallback = () => {
        console.warn('purchaseCallback not configured');
    };
    return {
        initPurchase: (params) => __awaiter(void 0, void 0, void 0, function* () {
            console.debug('fakePurchase.initPurchase', params);
            setTimeout(() => {
                purchaseCallback({
                    paymentId: 'fakePurchaseId',
                    purchaseParams: params,
                    status: 'paid',
                });
            });
            return 'fakePurchaseId';
        }),
        onPurchase: (callback = defaultHandler) => {
            purchaseCallback = callback;
        },
    };
};
const defaultHandler = () => {
    console.warn('purchaseCallback not configured');
};
export function createPurchase(p00lsApi, logEvent, getIdToken) {
    let pendingPurchase = null;
    let purchaseCallback = defaultHandler;
    on('invoice_closed', (e) => {
        if (!pendingPurchase) {
            return;
        }
        if (e.slug !== pendingPurchase.slug) {
            return;
        }
        if (e.status === 'paid') {
            logEvent('purchase', toPurchaseEvent(pendingPurchase));
        }
        const callbackParams = {
            paymentId: pendingPurchase.purchaseId,
            purchaseParams: pendingPurchase.params,
            status: e.status,
        };
        pendingPurchase = null;
        purchaseCallback(callbackParams);
    });
    function initPurchase(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const idToken = yield getIdToken();
            const { invoiceLink, purchaseId, usdValue } = yield p00lsApi.createInvoiceLink(params, idToken);
            const url = new URL(invoiceLink);
            const slug = url.pathname.split('/')[1].replace('$', '');
            pendingPurchase = { params, purchaseId, slug, usdValue };
            logEvent('begin_checkout', toCheckoutEvent(params, usdValue));
            postEvent('web_app_open_invoice', { slug });
            return purchaseId;
        });
    }
    function onPurchase(handler = defaultHandler) {
        purchaseCallback = handler;
    }
    return { initPurchase, onPurchase };
}
function toCheckoutEvent(params, usdValue) {
    if (isBuyCurrencyParams(params)) {
        return {
            value: usdValue,
            currency: 'USD',
            items: [
                {
                    item_id: params.symbol,
                    item_name: params.name,
                    quantity: params.quantity,
                    price: usdValue / params.quantity,
                },
            ],
        };
    }
    if (isBuyItemParams(params)) {
        return {
            value: usdValue,
            currency: 'USD',
            items: [
                {
                    item_id: params.itemId,
                    item_name: params.title,
                    quantity: params.quantity,
                    price: usdValue / params.quantity,
                },
            ],
        };
    }
    return {};
}
function toPurchaseEvent({ purchaseId, params, usdValue }) {
    if (isBuyCurrencyParams(params)) {
        return {
            value: usdValue,
            transaction_id: purchaseId,
            currency: 'USD',
            items: [
                {
                    item_id: params.symbol,
                    item_name: params.name,
                    quantity: params.quantity,
                    price: usdValue / params.quantity,
                },
            ],
        };
    }
    if (isBuyItemParams(params)) {
        return {
            value: usdValue,
            currency: 'USD',
            transaction_id: purchaseId,
            items: [
                {
                    item_id: params.itemId,
                    item_name: params.title,
                    quantity: params.quantity,
                    price: usdValue / params.quantity,
                },
            ],
        };
    }
    return {};
}
//# sourceMappingURL=purchase.js.map