import { __awaiter } from "tslib";
import { collection, doc, getCountFromServer, getDoc, getDocs, limit, orderBy, query, startAfter, Timestamp, where, } from 'firebase/firestore';
export const fakeReferral = {
    getReferralLink() {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve('fakelink');
        });
    },
    getReferrer() {
        return __awaiter(this, void 0, void 0, function* () {
            return undefined;
        });
    },
    getReferees() {
        return __awaiter(this, void 0, void 0, function* () {
            return { page: [], total: 0 };
        });
    },
    shareLink() {
        return __awaiter(this, void 0, void 0, function* () {
            console.debug('Fake referral: Share link');
        });
    },
};
export function createReferral(db, p00lsApi, getIdToken, connectedUser, shareFunction) {
    let referralLink;
    return {
        getReferralLink,
        getReferrer() {
            return __awaiter(this, void 0, void 0, function* () {
                if (!connectedUser.referrer) {
                    return;
                }
                const snap = yield getDoc(doc(db, `referral-links`, connectedUser.referrer));
                if (!snap.exists()) {
                    return;
                }
                return {
                    firstName: snap.get('firstName'),
                };
            });
        },
        getReferees,
        shareLink() {
            return __awaiter(this, arguments, void 0, function* (message = 'Come and play this game with me!') {
                const link = yield getReferralLink();
                shareFunction(link, message);
            });
        },
    };
    function getReferralLink() {
        if (referralLink) {
            return referralLink;
        }
        referralLink = (() => __awaiter(this, void 0, void 0, function* () {
            const token = yield getIdToken();
            const { link } = yield p00lsApi.getReferralLink(token);
            return link;
        }))();
        return referralLink;
    }
    function getReferees(_a) {
        return __awaiter(this, arguments, void 0, function* ({ next, pageSize = 10, since, }) {
            const q = [where('gameId', '==', connectedUser.game)];
            if (typeof next !== 'undefined') {
                const { total, cursor, pageSize, since } = decodeNext(next);
                q.push(...[
                    ...(since
                        ? [where('createdAt', '>', Timestamp.fromMillis(since))]
                        : []),
                    orderBy('createdAt', 'desc'),
                    startAfter(Timestamp.fromMillis(cursor)),
                    limit(Math.min(pageSize, 25)),
                ]);
                const referees = yield doFetchReferees(q);
                return wrapResponse(referees, total, pageSize, since);
            }
            const col = collection(db, `/users/${connectedUser.userId}/user-referees`);
            if (since) {
                q.push(where('createdAt', '>', Timestamp.fromDate(since)));
            }
            const total = (yield getCountFromServer(query(col, ...q))).data().count;
            q.push(...[orderBy('createdAt', 'desc'), limit(Math.min(pageSize, 25))]);
            const referees = yield doFetchReferees(q);
            return wrapResponse(referees, total, pageSize, since && since.getTime());
        });
    }
    function wrapResponse(referees, total, pageSize, since) {
        const next = referees.length === pageSize
            ? encodeNext(total, pageSize, referees[referees.length - 1].createdAt, since)
            : undefined;
        return {
            page: referees,
            total,
            next,
        };
    }
    function doFetchReferees(q) {
        return __awaiter(this, void 0, void 0, function* () {
            const col = collection(db, `/users/${connectedUser.userId}/user-referees`);
            const snap = yield getDocs(query(col, ...q));
            return snap.docs.map((doc) => ({
                firstName: doc.get('firstName'),
                createdAt: doc.get('createdAt').toDate(),
            }));
        });
    }
    function encodeNext(total, pageSize, next, since) {
        const urlSearchParams = new URLSearchParams({
            t: `${total}`,
            s: `${pageSize}`,
            c: `${next.getTime()}`,
        });
        if (since) {
            urlSearchParams.append('q', `${since}`);
        }
        return urlSearchParams.toString();
    }
    function decodeNext(value) {
        const values = new URLSearchParams(value);
        console.log(value);
        return Object.assign({ total: Number(values.get('t')), cursor: Number(values.get('c')), pageSize: Number(values.get('s')) }, (values.get('q') ? { since: Number(values.get('q')) } : {}));
    }
}
//# sourceMappingURL=referral.js.map