import { __awaiter } from "tslib";
function getLocalStatistics() {
    const maybeItem = localStorage.getItem(`fakeGame_statistics`);
    return maybeItem ? JSON.parse(maybeItem) : {};
}
export const fakeStatistics = {
    fetchLeaderboard(statistic, params) {
        console.log('fetchLeaderboard', statistic, params);
        const userValue = getLocalStatistics()[statistic];
        return Promise.resolve({
            entries: userValue
                ? [
                    {
                        userId: 1,
                        position: 1,
                        value: userValue.value,
                        displayName: 'Me',
                    },
                ]
                : [],
            version: 1,
        });
    },
    fetchLeaderboardAround(statistic) {
        console.log('fetchLeaderboardAround', statistic);
        const userValue = getLocalStatistics()[statistic];
        return Promise.resolve({
            entries: userValue
                ? [
                    {
                        userId: 1,
                        position: 1,
                        value: userValue.value,
                        displayName: 'Me',
                    },
                ]
                : [],
            version: 1,
        });
    },
    fetchLeaderboardPosition(statistic) {
        console.log('fetchLeaderboardPosition', statistic);
        const value = getLocalStatistics()[statistic];
        if (!value) {
            return Promise.resolve(undefined);
        }
        return Promise.resolve(Object.assign({ position: 1 }, value));
    },
    fetchValues() {
        console.log('fetchValues');
        return Promise.resolve(getLocalStatistics());
    },
    updateValues(values) {
        console.log('updateValues', values);
        const maybeItem = getLocalStatistics();
        const stats = Object.keys(values).reduce((acc, v) => {
            const curVal = maybeItem[v] || {
                value: 0,
                version: 1,
            };
            curVal.value = values[v];
            acc[v] = curVal;
            return acc;
        }, maybeItem);
        localStorage.setItem(`fakeGame_statistics`, JSON.stringify(stats));
        return Promise.resolve();
    },
    changeDisplayName(newName) {
        console.log('Changing display name', newName);
        return Promise.resolve();
    },
};
export function createStatistics(p00lsApi, getIdToken) {
    let lastUpdate = Date.now() / 1000;
    setInterval(collectPlayingTime, 30 * 1000);
    function collectPlayingTime() {
        const elapsed = elapsedTime();
        if (elapsed < 30) {
            return;
        }
        doUpdateValues({}, elapsed).catch((e) => console.error(e));
    }
    function updateValues(updates) {
        return doUpdateValues(updates, elapsedTime());
    }
    function doUpdateValues(updates, elapsedTime) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = yield getIdToken();
            lastUpdate += elapsedTime;
            yield p00lsApi.sendApiRequest(token, 'statistics/values', {
                method: 'POST',
                body: JSON.stringify({ updates, elapsedTime: elapsedTime }),
            });
        });
    }
    function elapsedTime() {
        const now = Date.now() / 1000;
        return Math.floor(now - lastUpdate);
    }
    function changeDisplayName(newName_1) {
        return __awaiter(this, arguments, void 0, function* (newName, custom = false) {
            const token = yield getIdToken();
            yield p00lsApi.sendApiRequest(token, 'statistics/profiles', {
                method: 'POST',
                body: JSON.stringify({ displayName: newName, custom }),
            });
        });
    }
    function fetchValues() {
        return __awaiter(this, void 0, void 0, function* () {
            const token = yield getIdToken();
            return p00lsApi.sendApiRequest(token, 'statistics/values', {
                method: 'GET',
            });
        });
    }
    function fetchLeaderboardPosition(statistic) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = yield getIdToken();
            return p00lsApi.sendApiRequest(token, `statistics/leaderboard/position?statistic=${statistic}`, {
                method: 'GET',
            });
        });
    }
    function fetchLeaderboard(statistic_1) {
        return __awaiter(this, arguments, void 0, function* (statistic, { next, pageSize } = {}) {
            const token = yield getIdToken();
            const query = new URLSearchParams({ statistic });
            next && query.append('cursor', next);
            pageSize && query.append('pageSize', pageSize.toString());
            return p00lsApi.sendApiRequest(token, `statistics/leaderboard?${query.toString()}`, {
                method: 'GET',
            });
        });
    }
    function fetchLeaderboardAround(statistic_1) {
        return __awaiter(this, arguments, void 0, function* (statistic, { pageSize } = {}) {
            const token = yield getIdToken();
            const query = new URLSearchParams({ statistic });
            pageSize && query.append('pageSize', pageSize.toString());
            return yield p00lsApi.sendApiRequest(token, `statistics/leaderboard/around?${query.toString()}`, {
                method: 'GET',
            });
        });
    }
    return {
        changeDisplayName,
        updateValues,
        fetchValues,
        fetchLeaderboardPosition,
        fetchLeaderboard,
        fetchLeaderboardAround,
    };
}
//# sourceMappingURL=statistics.js.map