import { __awaiter } from "tslib";
import { setDebug, backButton, closeMiniApp, getCurrentTime, hapticFeedbackImpactOccurred, hapticFeedbackNotificationOccurred, hapticFeedbackSelectionChanged, init as initTma, openLink as tgOpenLink, openTelegramLink as tgOpenTelegramLink, postEvent, restoreInitData, shareURL, } from '@telegram-apps/sdk';
const launcherLink = {
    devel: 'https://t.me/semag_sl00p_devel_bot?startapp',
    prod: 'https://t.me/p00ls_games_bot?startapp',
    local: '',
};
export function createTelegram(env, onClose, isInFullscreen, mountBack, isMobile) {
    initTma();
    setDebug(env !== 'prod');
    restoreInitData();
    backButton.mount.ifAvailable();
    if (mountBack) {
        backButton.show.ifAvailable();
        backButton.onClick.ifAvailable(openP00LSGamesLauncher);
    }
    function haptic(type, style) {
        if (type === 'impact') {
            hapticFeedbackImpactOccurred.ifAvailable(style);
        }
        if (type === 'select') {
            hapticFeedbackSelectionChanged.ifAvailable();
        }
        if (type === 'notification') {
            hapticFeedbackNotificationOccurred.ifAvailable(style);
        }
    }
    function getServerTime() {
        return __awaiter(this, void 0, void 0, function* () {
            const [, val] = getCurrentTime.ifAvailable();
            return (yield val) || new Date();
        });
    }
    function share(url, description) {
        shareURL.ifAvailable(url, description);
    }
    function openLink(url) {
        tgOpenLink(url);
    }
    function openTelegramLink(path, shouldClose = isMobile) {
        tgOpenTelegramLink(path);
        if (shouldClose) {
            setTimeout(close, 500);
        }
    }
    function openP00LSGamesLauncher() {
        if (isMobile) {
            openTelegramLink(launcherLink[env]);
        }
        else {
            close();
        }
    }
    function close() {
        onClose().then(() => closeMiniApp.ifAvailable());
    }
    return {
        ready() {
            postEvent('web_app_expand');
            postEvent('web_app_setup_swipe_behavior', {
                allow_vertical_swipe: false,
            });
            if (isInFullscreen) {
                console.debug('fullscreen enabled');
                postEvent('web_app_request_fullscreen');
            }
            postEvent('web_app_ready');
        },
        haptic,
        getServerTime,
        share,
        openLink,
        openTelegramLink,
        openP00LSGamesLauncher,
        isInFullscreen,
        close,
    };
}
export const fakeTelegram = {
    ready() {
        return;
    },
    haptic() {
        return;
    },
    getServerTime() {
        return Promise.resolve(new Date());
    },
    share(url, description) {
        console.log('Fake telegram. Share', url, description);
    },
    openLink(url) {
        window.open(url);
    },
    openTelegramLink(url) {
        console.log('Fake telegram. Open tg link', url);
    },
    openP00LSGamesLauncher() {
        console.log('Fake telegram. Open launcher');
    },
    close() {
        console.log('Fake telegram. Close');
    },
    isInFullscreen: false,
};
//# sourceMappingURL=telegram.js.map