import { __awaiter } from "tslib";
export function retryableFetch(url_1) {
    return __awaiter(this, arguments, void 0, function* (url, fetchOptions = { cache: 'no-cache' }, retryOptions = {
        attempt: 1,
        maxAttempt: 10,
        baseDelayMs: 100,
    }) {
        let currentAttempt = retryOptions.attempt;
        const retryableStatuses = [502, 503, 504];
        try {
            const result = yield fetch(url, fetchOptions);
            if (!retryableStatuses.includes(result.status)) {
                return result;
            }
            else {
                if (currentAttempt >= retryOptions.maxAttempt) {
                    console.warn(`An error occurred while fetching, response code`, result.status);
                    throw new Error('Bad response code');
                }
            }
        }
        catch (e) {
            if (currentAttempt >= retryOptions.maxAttempt) {
                console.warn(`An error occurred while fetching, Exception catched`, e);
                throw new Error(`Maximum retries reached: ${currentAttempt}`);
            }
        }
        const delayMs = retryOptions.baseDelayMs * Math.pow(2, currentAttempt);
        currentAttempt++;
        yield new Promise((resolve) => setTimeout(resolve, delayMs));
        return retryableFetch(url, fetchOptions, {
            attempt: currentAttempt,
            maxAttempt: retryOptions.maxAttempt,
            baseDelayMs: retryOptions.baseDelayMs,
        });
    });
}
//# sourceMappingURL=retryableFetch.js.map